==> aspectran-core-5.1.0-sources.jar: com/aspectran/core/component/template/engine/TemplateEngineProcessException.java <==
/*
 * Copyright (c) 2008-2018 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.component.template.engine;

import com.aspectran.core.context.AspectranCheckedException;

/**
 * The Class TemplateEngineProcessException.
 * 
 * <p>Created: 2016. 01. 23.</p>
 */
public class TemplateEngineProcessException extends AspectranCheckedException {

    /** @serial */
    private static final long serialVersionUID = 3136366504332981036L;

    /**
     * Instantiates a new TemplateEngineProcessException.
     *
     * @param msg the detail message
     */
    public TemplateEngineProcessException(String msg) {
        super(msg);
    }

    /**
     * Instantiates a new TemplateEngineProcessException.
     *
     * @param msg the detail message
     * @param cause the root cause
     */
    public TemplateEngineProcessException(String msg, Throwable cause) {
        super(msg, cause);
    }

    /**
     * Instantiates a new TemplateEngineProcessException.
     *
     * @param cause the root cause
     */
    public TemplateEngineProcessException(Throwable cause) {
        super(cause);
    }

}

==> aspectran-core-6.13.3-sources.jar: com/aspectran/core/component/template/engine/TemplateEngineProcessException.java <==
/*
 * Copyright (c) 2008-2021 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.component.template.engine;

/**
 * The Class TemplateEngineProcessException.
 * 
 * <p>Created: 2016. 01. 23.</p>
 */
public class TemplateEngineProcessException extends Exception {

    /** @serial */
    private static final long serialVersionUID = 3136366504332981036L;

    /**
     * Instantiates a new TemplateEngineProcessException.
     *
     * @param msg the detail message
     */
    public TemplateEngineProcessException(String msg) {
        super(msg);
    }

    /**
     * Instantiates a new TemplateEngineProcessException.
     *
     * @param msg the detail message
     * @param cause the root cause
     */
    public TemplateEngineProcessException(String msg, Throwable cause) {
        super(msg, cause);
    }

    /**
     * Instantiates a new TemplateEngineProcessException.
     *
     * @param cause the root cause
     */
    public TemplateEngineProcessException(Throwable cause) {
        super(cause);
    }

}
